%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%
% Monetary Policy on the Path
% quarterly averages
% 10 year Futures
%%%%%%%

F10yF_ir_table = readtable('Interpolation.xlsx','Sheet','10yF_ir_t_q');%Interpolated 10Y Futures interest rates 0 - 4 quaters ahead
Act_10y = readtable('PolicyMeasures_data_FFFappend_TKN.xlsx','Sheet','Act_10y_q');%Actual 10y interest rates
Date_table = readtable('PolicyMeasures_data_FFFappend_TKN.xlsx','Sheet','Date');%yearmonth, Year, Month

%%%%%%%
% 10Y Futures - on Path
% quarterly averages
% tau = 0.10
%%%%%%%

%Note: NaN shows up as Not on Path.  Double check dates
%ZLB NaN dates: 2009:10, 2010:04, 2010:05, 2010:07

F10yF = F10yF_ir_table{1:440,2:6}; %BC 10Y forecasts; 1982:01 - 2018:08
ACTUAL = Act_10y{202:641,2:6}; %Actual 10Y horizon 0 - 4 quarters; 1982:01 - 2018:08
month = Date_table{1:440,3};

tau = 0.10;
T = size(F10yF,1);
Z = size(F10yF,2);
Date = Date_table{1:T,1};

ir_top = zeros(T,Z);
ir_bot = zeros(T,Z);
F10yF_q1_path = zeros(T,Z);
for h = 1 : Z
    if h==1 %h = 0 and h = 1 have the same bandwidth under this specification
        ir_top(:,h) = F10yF(:,h) * (1 + tau)^h;
        ir_bot(:,h) = F10yF(:,h) * (1 - tau)^h;
    else
        ir_top(:,h) = F10yF(:,h) * (1 + tau)^(h-1);
        ir_bot(:,h) = F10yF(:,h) * (1 - tau)^(h-1);
    end
end
F10yF_q1_path = (ACTUAL < ir_top) .* (ACTUAL > ir_bot);
ir_interp1 = array2table(F10yF_q1_path);
ir_interp1_t = addvars(ir_interp1,Date,'Before','F10yF_q1_path1');
writetable(ir_interp1_t,'T10YFutures_q.xlsx','Sheet','F10yF_q1_path','WriteVariableNames',true);


%%%%%%%
% 10Y Futures  - on Path
% once not on path, cannot be on path in the future
% tau = 0.10
%%%%%%%

%Note: NaN shows up as Not on Path.  Double check dates
%ZLB NaN dates: 2009:10, 2010:04, 2010:05, 2010:07

F10yF_S1_MTO(:,1) = F10yF_q1_path(:,1);
for i = 1:T
    for h = 2:Z
        F10yF_S1_MTO(i,h) = F10yF_S1_MTO(i,h-1) .* F10yF_q1_path(i,h);
    end
end
ir_S1_MTO_table = array2table(F10yF_S1_MTO);
ir_S1_MTO_t = addvars(ir_S1_MTO_table,Date,'Before','F10yF_S1_MTO1');
writetable(ir_S1_MTO_t,'T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO','WriteVariableNames',true);

%Create Variables to use for Encompassing Regressions
%on path, monthly
% 1 = acutal Fed Funds Rate is within range of futures
F10yF_S1_MTO_p = F10yF_S1_MTO(:,1:Z);
F10yF_S1_MTO_p(F10yF_S1_MTO_p==0) = NaN;
F10yF_S1_MTO_p_t = array2table(F10yF_S1_MTO_p);
x = addvars(F10yF_S1_MTO_p_t,Date,'Before','F10yF_S1_MTO_p1');
writetable(x,'T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO_p','WriteVariableNames',true);

%not on path
%ZLB NaN dates: 2009:10, 2010:04, 2010:05, 2010:07
F10yF_S1_MTO_np(334,:) = 0;
F10yF_S1_MTO_np(340:341,:) = 0;
F10yF_S1_MTO_np(343,:) = 0;

F10yF_S1_MTO_np = F10yF_S1_MTO(:,1:Z);
F10yF_S1_MTO_np(F10yF_S1_MTO_np==1) = -1;
F10yF_S1_MTO_np(F10yF_S1_MTO_np==0) = 1;
F10yF_S1_MTO_np(F10yF_S1_MTO_np==-1) = NaN;
F10yF_S1_MTO_np_t = array2table(F10yF_S1_MTO_np);
x = addvars(F10yF_S1_MTO_np_t,Date,'Before','F10yF_S1_MTO_np1');
writetable(x,'T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO_np','WriteVariableNames',true);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
