%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% 10y Futures Interpolation
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

F10y_table = readtable('PolicyMeasures_data_FFFappend_TKN.xlsx','Sheet','10YR Treasury Futures','PreserveVariableNames',true); %Eurodollar
Date_table = readtable('PolicyMeasures_data_FFFappend_TKN.xlsx','Sheet','Date');%yearmonth, Year, Month

%%%%%%%
% Linear Interpolation
%%%%%%%

X = F10y_table{1:472,2:14}; %1982:01 - 2021:04
T = size(X,1);

F10y = zeros(T,13);
for t = 1 : T
    [F10y(t,:),TF(t,:)] = fillmissing(X(t,:),'linear');
end

Date = F10y_table{1:T,1};
F10y_interp = array2table(F10y);
x = addvars(F10y_interp,Date,'Before','F10y1');
writetable(x,'Interpolation.xlsx','Sheet','10yF_interp','WriteVariableNames',true);

Date = F10y_table{1:T,1};
TF_interp = array2table(TF);
x = addvars(TF_interp,Date,'Before','TF1');
writetable(x,'Interpolation.xlsx','Sheet','10yF_TF_interp','WriteVariableNames',true);


%transform into interest rates
%equation from Owyang Aug2022
P = F10y;
N = 10;
ir = N./log(P);
ir_interp = array2table(ir);
x = addvars(ir_interp,Date,'Before','ir1');
writetable(x,'Interpolation.xlsx','Sheet','F10y_ir_interp','WriteVariableNames',true);

%%%%%%%
% Transform Monthly Data to Quarterly Averages
%%%%%%%
Date = F10y_table{1:T,1};
month = Date_table{1:T,3};

ir_t = addvars(x,month,'Before','Date');
ir_t_q = zeros(T,5);
for t = 1 : T
        if ir_t{t,1}==1 || ir_t{t,1}==4 || ir_t{t,1}==7 || ir_t{t,1}==10 %first M of quarter
        ir_t_q(t,1) = mean(ir_t{t,3:5},2);
        ir_t_q(t,2) = mean(ir_t{t,6:8},2);
        ir_t_q(t,3) = mean(ir_t{t,9:11},2);
        ir_t_q(t,4) = mean(ir_t{t,12:14},2);
        ir_t_q(t,5) = mean(ir_t{t,15},2);
        elseif ir_t{t,1}==2 || ir_t{t,1}==5 || ir_t{t,1}==8 || ir_t{t,1}==11  %2nd M of quarter
        ir_t_q(t,1) = mean(ir_t{t,3:4},2);
        ir_t_q(t,2) = mean(ir_t{t,5:7},2);
        ir_t_q(t,3) = mean(ir_t{t,8:10},2);
        ir_t_q(t,4) = mean(ir_t{t,11:13},2);
        ir_t_q(t,5) = mean(ir_t{t,14:15},2);
        else 
        ir_t_q(t,1) = mean(ir_t{t,3},2);
        ir_t_q(t,2) = mean(ir_t{t,4:6},2);
        ir_t_q(t,3) = mean(ir_t{t,7:9},2);
        ir_t_q(t,4) = mean(ir_t{t,10:12},2);
        ir_t_q(t,5) = mean(ir_t{t,13:15},2);
        end
end

ir_q = array2table(ir_t_q);
ir_q_t = addvars(ir_q,Date,'Before','ir_t_q1');
writetable(ir_q_t,'Interpolation.xlsx','Sheet','10yF_ir_t_q','WriteVariableNames',true);
