%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%
% Monetary Policy on the Path
% quarterly averages
%%%%%%%

ED_ir_table = readtable('Interpolation.xlsx','Sheet','ED_ir_t_q');%Interpolated EuroDollar interest rates 0 - 4 quaters ahead
FFR_table = readtable('PolicyMeasures_data_FFFappend_TKN.xlsx','Sheet','FFRq');%Federal Funds Rate horizon 0 - 4 quarters ahead
Date_table = readtable('PolicyMeasures_data_FFFappend_TKN.xlsx','Sheet','Date');%yearmonth, Year, Month

%%%%%%%
% Eurodollar futures  - on Path
% quarterly averages
% tau = 0.05
%%%%%%%

% ir is the interest rate implied by the Eurodollar futures interpolated
    % monthly and averaged
ir = ED_ir_table{1:472,2:6}; %Interpolated EuroDollar interest rates 0 - 4 quarters ahead; 1982:01 - 2021:04
ACTUAL = FFR_table{25:496,2:6}; %Federal Funds Rate horizon 0 - 4 quarters; 1982:01 - 2021:04
month = Date_table{1:472,3};

tau = 0.05;
T = size(ir,1);
Date = ED_ir_table{1:T,1};

ir_top = zeros(T,5);
ir_bot = zeros(T,5);
ir_path = zeros(T,5);
for h = 1 : 5
    if h==1 %h = 0 and h = 1 have the same bandwidth under this specification
        ir_top(:,h) = ir(:,h) * (1 + tau)^h;
        ir_bot(:,h) = ir(:,h) * (1 - tau)^h;
    else
        ir_top(:,h) = ir(:,h) * (1 + tau)^(h-1);
        ir_bot(:,h) = ir(:,h) * (1 - tau)^(h-1);
    end
end
ir_path = (ACTUAL < ir_top) .* (ACTUAL > ir_bot);
ir_interp = array2table(ir_path);
ir_interp_t = addvars(ir_interp,Date,'Before','ir_path1');
writetable(ir_interp_t,'EuroDollar_q.xlsx','Sheet','ir_q05_path','WriteVariableNames',true);


%%%%%%%
% Eurodollar futures  - on Path
% once not on path, cannot be on path in the future
% tau =0.05
%%%%%%%

ir_MTO(:,1) = ir_path(:,1);
for i = 1:T
    for h = 2:5
        ir_MTO(i,h) = ir_MTO(i,h-1) .* ir_path(i,h);
    end
end
ir_MTO_table = array2table(ir_MTO);
ir_MTO_t = addvars(ir_MTO_table,Date,'Before','ir_MTO1');
writetable(ir_MTO_t,'EuroDollar_q.xlsx','Sheet','ir_S05_MTO','WriteVariableNames',true);

%Create Variables to use for Encompassing Regressions
%on path, monthly
% 1 = acutal Fed Funds Rate is within range of futures
ir_MTO_p = ir_MTO(:,1:5);
ir_MTO_p(ir_MTO_p==0) = NaN;
ir_MTO_p_t = array2table(ir_MTO_p);
x = addvars(ir_MTO_p_t,Date,'Before','ir_MTO_p1');
writetable(x,'EuroDollar_q.xlsx','Sheet','ir_S05_MTO_p','WriteVariableNames',true);

%not on path
ir_MTO_np = ir_MTO(:,1:5);
ir_MTO_np(ir_MTO_np==1) = -1;
ir_MTO_np(ir_MTO_np==0) = 1;
ir_MTO_np(ir_MTO_np==-1) = NaN;
ir_MTO_np_t = array2table(ir_MTO_np);
x = addvars(ir_MTO_np_t,Date,'Before','ir_MTO_np1');
writetable(x,'EuroDollar_q.xlsx','Sheet','ir_S05_MTO_np','WriteVariableNames',true);
