%Table 1 - Conventional Encompassign Test Results - Inflation
%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%%%%%%%%%%%%%
%
%  Encompassing Test
%
% Tests of Federal Reserve Additional Information for GNP/GDP Price Index Forecasts: 
% u_{h,t} = \delta + \gamma_{C} \hat{u}_{h,t}^{C} + \gamma_{F} \hat{u}_{h,t}^{F} +\nu_{h,t} 
%
% Blue Chip & Greenbook/Fed
%
%%%%%%%%%%%%%%%%%%%

addpath(genpath('/Applications/MATLAB_R2021b.app/toolbox/LeSage/'))

%load data

Actual_d = readtable('Data_main.xlsx','Sheet','Actual','ReadRowNames',1); 
BC_d = readtable('Data_main.xlsx','Sheet','BC_data','ReadRowNames',1); 
Fed_d = readtable('Data_main.xlsx','Sheet','Greenbook_data','ReadRowNames',1); 

%%%Full Sample

%Storing results for regressions
result_Table1=cell(8,8);  %Newey-West

%Storing results for F-tests
fstat_Table1=cell(8,8);

%Loop for regressions and F-tests
for i = 1:8
    %define variables       
    %full data set 1968:11 - 1995:11, 1996:05-2016:12
   
    t1 = datetime(1965,04,01);
    t = dateshift(t1,'start','month',0:620)';
    
    date1 = t(44:320,1); %1968:11 - 1991:11 
    date2 = t(322:369,1); %1992:01-1995:12
    date3 = t(374:621,1); %1996:05-2016:12
    date = vertcat(date1,date2, date3);
    
    inf1= Actual_d{41+3*i:317+3*i,3}; %first final release 1968:11 - 1991:11 GNP def
    inf2 = Actual_d{319+3*i:366+3*i,6}; %1992:01 - 1995:12 Price index for GDP, implicit deflator
    inf3= Actual_d{371+3*i:618+3*i,9}; %1996:05-2016:12 GDP, chain weighted
    inf = vertcat(inf1,inf2,inf3);
    
    BC_1 = BC_d{44:320,112+i}; %1968:11 - 1991:11 
    BC_2 = BC_d{322:369,112+i}; %1992:01-1995:12
    BC_3 = BC_d{374:621,112+i}; %1996:05-2016:12
    BC_i = vertcat(BC_1,BC_2, BC_3);
    
    Fed_1 = Fed_d{44:320,4+i}; %1968:11 - 1991:11
    Fed_2 = Fed_d{322:369,4+i}; %1992:01-1995:12
    Fed_3 = Fed_d{374:621,4+i}; %1996:05-2016:12 
    Fed_i = vertcat(Fed_1,Fed_2,Fed_3);
    
    A = size(BC_i,1);
    x = [ones(A,1) BC_i Fed_i];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(date,inf,BC_i,Fed_i);
    
    %Newey-West
    result_Table1{i} = nwest3_en(inf,x,T); %B_p = 0, B_f = 1
    fid = fopen('table1_BC_update_NW.out','a+');
    prt_reg_nw(result_Table1{i}, vnames,fid);
    %F-test
    %not testing intercept
    fstat_Table1{i} = waldf_table1a(result_Table1{i});
    fid = fopen('table1_BC_update_NW.out','a+');
    prt_reg_f(fstat_Table1{i}, [],fid)
  
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prior to and after 1994
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Loop for regressions and F-tests
for i = 1:8

    %1968:11 - 1993:12    
    inf1= Actual_d{41+3*i:317+3*i,3}; %first final release 1968:11 - 1991:11 GNP def
    inf2 = Actual_d{319+3*i:342+3*i,6}; %1992:01 - 1993:12 Price index for GDP, implicit deflator
    inf = vertcat(inf1,inf2);

    BC_1 = BC_d{44:320,112+i}; %1968:11 - 1991:11 
    BC_2 = BC_d{322:345,112+i}; %1992:01-1993:12
    BC_i = vertcat(BC_1,BC_2);
    
    Fed_1 = Fed_d{44:320,4+i}; %1968:11 - 1991:11
    Fed_2 = Fed_d{322:345,4+i}; %1992:01-1993:12 
    Fed_i = vertcat(Fed_1,Fed_2);

    date1 = t(44:320,1); %1968:11 - 1991:11 
    date2 = t(322:345,1); %1992:01-1993:12 
    date = vertcat(date1,date2);
    
    A = size(BC_i,1);
    x = [ones(A,1) BC_i Fed_i];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(date,inf,BC_i,Fed_i);
    
    %Newey-West 
    result_Table1{i,2} = nwest3_en(inf,x,T); %B_p = 0, B_f = 1
    fid = fopen('table1_BC_p94_NW.out','a+');
    prt_reg_nw(result_Table1{i,2},vnames,fid);
    %F-test
    fstat_Table1{i,2} = waldf_table1a(result_Table1{i,2});
    fid = fopen('table1_BC_p94_NW.out','a+');
    prt_reg_f(fstat_Table1{i,2}, [],fid)
    
    
    %after 1994
    inf2 = Actual_d{343+3*i:366+3*i,6}; %1994:01 - 1995:12 Price index for GDP, implicit deflator
    inf3= Actual_d{371+3*i:618+3*i,9}; %1996:05-2016:12 GDP, chain weighted
    inf = vertcat(inf2,inf3);
        
    BC_2 = BC_d{346:369,112+i}; %1994:01-1995:12
    BC_3 = BC_d{374:621,112+i}; %1996:05-2016:12
    BC_i = vertcat(BC_2,BC_3);

    Fed_2 = Fed_d{346:369,4+i}; %1994:01-1995:12
    Fed_3 = Fed_d{374:621,4+i}; %1996:05-2016:12 
    Fed_i = vertcat(Fed_2,Fed_3);

    date2 = t(346:369,1); %1994:01-1995:12
    date3 = t(374:621,1); %1996:05-2016:12
    date = vertcat(date2,date3);
    
    A = size(BC_i,1);
    x = [ones(A,1) BC_i Fed_i];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(date,inf,BC_i,Fed_i);
    
    %Newey-West
    result_Table1{i,3} = nwest3_en(inf,x,T); %B_p = 0, B_f = 1
    fid = fopen('table1_BC_a94_NW.out','a+');
    prt_reg_nw(result_Table1{i,3},vnames,fid);
    %F-test
    fstat_Table1{i,3} = waldf_table1a(result_Table1{i,3});
    fid = fopen('table1_BC_a94_NW.out','a+');
    prt_reg_f(fstat_Table1{i,3}, [],fid)
end



