%Table 2: IV Encompassing Test Results - Inflation
%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%%%%%%%%%%%%%
%
%  Encompassing Test with BC
%
%  IV Federal Reserve with other BC forecasts 
%
% Tests of Federal Reserve Additional Information for GNP/GDP Price Index Forecasts: 
% u_{h,t} = \delta + \gamma_{BC} \hat{u}_{h,t}^{BC} + \gamma_{F} \hat{u}_{h,t}^{F} +\nu_{h,t} 
%
% Blue Chip & Greenbook/Fed
%
%%%%%%%%%%%%%%%%%%%

addpath(genpath('/Applications/MATLAB_R2021b.app/toolbox/LeSage/'))

%load data
Actual_d = readtable('Data_main.xlsx','Sheet','Actual','ReadRowNames',1); 
BC_d = readtable('Data_main.xlsx','Sheet','BC_data','ReadRowNames',1); 
Fed_d = readtable('Data_main.xlsx','Sheet','Greenbook_data','ReadRowNames',1); 

%%%%%%%%%%%%%%%
%%% Full Sample
%%%%%%%%%%%%%%%

%Storing results for regressions
result_A = cell(8,3); %Full Sample - homoskedastic
result_Table2= cell(8,3); %2nd stage - NW

%Storing results for F-tests
fstat_Table2_F = cell(8,3); %First stage F-Stat
fstat_Table2 = cell(8,3); %2nd Stage Encompassing

for i= 1:8
    
    t1 = datetime(1965,04,01);
    t = dateshift(t1,'start','month',0:620)';
    
    date1 = t(44:320,1); %1968:11 - 1991:11 
    date2 = t(322:369,1); %1992:01-1995:12
    date3 = t(374:621,1); %1996:05-2016:12
    date = vertcat(date1,date2,date3);
    
    %Inflation - Deflator
    inf1= Actual_d{41+3*i:317+3*i,3}; %first final release 1968:11 - 1991:11 GNP def
    inf2 = Actual_d{319+3*i:366+3*i,6}; %1992:01 - 1995:12 Price index for GDP, implicit deflator
    inf3= Actual_d{371+3*i:618+3*i,9}; %1996:05-2016:12 GDP, chain weighted
    inf = vertcat(inf1,inf2,inf3);
    
    BC_1 = BC_d{44:320,112+i}; %1968:11 - 1991:11 
    BC_2 = BC_d{322:369,112+i}; %1992:01-1995:12
    BC_3 = BC_d{374:621,112+i}; %1996:05-2016:12
    BC_i = vertcat(BC_1,BC_2, BC_3);
    
    Fed_1 = Fed_d{44:320,4+i}; %1968:11 - 1991:11
    Fed_2 = Fed_d{322:369,4+i}; %1992:01-1995:12
    Fed_3 = Fed_d{374:621,4+i}; %1996:05-2016:12 
    Fed_i = vertcat(Fed_1,Fed_2,Fed_3);

    BC_t3m1 = BC_d{44:320,32+i}; %1980:10 - 1991:11  -- Z - 3 Month Treasury Bill Yield
    BC_t3m2 = BC_d{322:369,32+i}; %1992:01 - 1995:09  -- Z - 3 Month Treasury Bill Yield
    BC_t3m3 = BC_d{374:621,32+i}; %1996:05-2016:12   -- Z - 3 Month Treasury Bill Yield
    BC_t3m = vertcat(BC_t3m1,BC_t3m2, BC_t3m3);
    
    BC_u1 = BC_d{44:320,42+i}; %1980:02 - 1991:11  -- Z - unemployment rate 
    BC_u2 = BC_d{322:369,42+i}; %1992:01 - 1995:09  -- Z - unemployment rate 
    BC_u3 = BC_d{374:621,42+i}; %1996:05-2016:12  -- Z - unemployment rate 
    BC_u = vertcat(BC_u1,BC_u2, BC_u3);
    
    BC_y1 = BC_d{44:320,102+i}; %1980:01 - 1991:11  -- Z - Real Gross Domestic Product
    BC_y2 = BC_d{322:369,102+i}; %1992:01 - 1995:09  -- Z - Real Gross Domestic Product
    BC_y3 = BC_d{374:621,102+i}; %1996:05-2016:12  -- Z - Real Gross Domestic Product
    BC_y = vertcat(BC_y1,BC_y2, BC_y3);
    
    %First stage regression
    A = size(BC_i,1);
    x = [ones(A,1) BC_i BC_t3m BC_u BC_y]; 
    
    %1st stage: OLS regression
    result_A{i,1} = ols2(Fed_i,x);
    fid = fopen('result_A.out','a+');
    prt_reg2(result_A{i,1}, [],fid);
    %F-stat that IV = 0
    fstat_Table2_F{i,1} = waldf_1st_stage_multi3(result_A{i,1});
    fid = fopen('Table2_Full.out','a+');
    prt_reg_f(fstat_Table2_F{i,1}, [],fid);

    %Second Stage Regression
    A = size(Fed_i,1);
    xex = [ones(A,1) BC_i]; %includes ones and controls
    iv = [BC_t3m BC_u BC_y];
    T = table(date,inf,BC_i,Fed_i,BC_t3m,BC_u,BC_y);
    vnames = strvcat('inf','Fed IV','const','BC');
    %Second Stage - NW errors
    %tslsNW(dependent var,endogenous,all exog/controls,instrument)
    result_Table2{i,1} = tslsNW4(inf,Fed_i,xex,iv,T); 
    %output: beta = beta_endog beta_exo 
    %var1: Fed_IV, var2: constant, var3: SPF
    fid = fopen('Table2_Full.out','a+');
    prt_reg2(result_Table2{i,1},vnames,fid);
    %Encompassing Test - F-stat
    %not including intercept as a restriction
    fstat_Table2{i,1} = waldf_IVa(result_Table2{i,1});
    fid = fopen('Table2_Full.out','a+');
    prt_reg_f(fstat_Table2{i,1}, [],fid);
    
end


%%%%%%%%%%%%%%%
% Prior to 1994
%%%%%%%%%%%%%%%

for i = 1:8
    %Infaltion Deflator
    %1968:11 - 1993:12
    
    date1 = t(44:320,1); %1968:11 - 1991:11 
    date2 = t(322:345,1); %1992:01-1993:12 
    date = vertcat(date1,date2);
 
    inf1= Actual_d{41+3*i:317+3*i,3}; %first final release 1968:11 - 1991:11 GNP def
    inf2 = Actual_d{319+3*i:342+3*i,6}; %1992:01 - 1993:12 Price index for GDP, implicit deflator
    inf = vertcat(inf1,inf2);
 
    BC_1 = BC_d{44:320,112+i}; %1968:11 - 1991:11 
    BC_2 = BC_d{322:345,112+i}; %1992:01-1993:12
    BC_i = vertcat(BC_1,BC_2);

    Fed_1 = Fed_d{44:320,4+i}; %1968:11 - 1991:11
    Fed_2 = Fed_d{322:345,4+i}; %1992:01-1993:12
    Fed_i = vertcat(Fed_1,Fed_2);

    BC_t3m1 = BC_d{44:320,32+i}; %1980:10 - 1991:11  -- Z - 3 Month Treasury Bill Yield
    BC_t3m2 = BC_d{322:345,32+i}; %1992:01 - 1993:12  -- Z - 3 Month Treasury Bill Yield
    BC_t3m = vertcat(BC_t3m1,BC_t3m2);
    
    BC_u1 = BC_d{44:320,42+i}; %1980:02 - 1991:11  -- Z - unemployment rate 
    BC_u2 = BC_d{322:345,42+i}; %1992:01 - 1993:12  -- Z - unemployment rate 
    BC_u = vertcat(BC_u1,BC_u2);
    
    BC_y1 = BC_d{44:320,102+i}; %1980:01 - 1991:11  -- Z - Real Gross Domestic Product
    BC_y2 = BC_d{322:345,102+i}; %1992:01 - 1993:12  -- Z - Real Gross Domestic Product
    BC_y = vertcat(BC_y1,BC_y2);
    
    % BC IV 1980: 3mTB, UR, rGDP
    %First stage regression
    A = size(BC_i,1);
    x = [ones(A,1) BC_i BC_t3m BC_u BC_y]; 
    %1st stage - OLS regression
    result_A{i,2} = ols2(Fed_i,x);
    fid = fopen('result_A.out','a+');
    prt_reg2(result_A{i,2}, [],fid);
    %F-stat that IV = 0
    fstat_Table2_F{i,2} = waldf_1st_stage_multi3(result_A{i,2});
    fid = fopen('Table2_p1994.out','a+');
    prt_reg_f(fstat_Table2_F{i,2}, [],fid);

    %Second stage regressions
    A = size(Fed_i,1);
    xex = [ones(A,1) BC_i]; %includes ones and controls
    iv = [BC_t3m BC_u BC_y];  
    vnames = strvcat('inf','Fed IV','const','BC');
    T = table(date,inf,BC_i,Fed_i,BC_t3m,BC_u,BC_y);
    %Second Stage - NW errors
    %tslsNW(dependent var,endogenous,all exog/controls,instrument)
    result_Table2{i,2} = tslsNW4(inf,Fed_i,xex,iv,T); 
    %result_Table2{i,2} = tslsNW(inf,Fed_i,xex,iv); 
    %output: beta = beta_endog beta_exo 
    %var1: Fed_IV, var2: constant, var3: SPF
    fid = fopen('Table2_p1994.out','a+');
    prt_reg2(result_Table2{i,2},vnames,fid);
    %Encompassing Test - F-stat
    %not including intercept as a restriction
    fstat_Table2{i,2} = waldf_IVa(result_Table2{i,2});
    fid = fopen('Table2_p1994.out','a+');
    prt_reg_f(fstat_Table2{i,2}, [],fid);
    
end
    

%%%%%%%%%%%%
% After 1994
%%%%%%%%%%%%


for i = 1:8    

    date2 = t(346:369,1); %1994:01-1995:12
    date3 = t(374:621,1); %1996:05-2016:12
    date = vertcat(date2,date3);
    
    inf2 = Actual_d{343+3*i:366+3*i,6}; %1994:01 - 1995:12 Price index for GDP, implicit deflator
    inf3= Actual_d{371+3*i:618+3*i,9}; %1996:05-2016:12 GDP, chain weighted
    inf = vertcat(inf2,inf3);

    BC_2 = BC_d{346:369,112+i}; %1994:01-1995:12
    BC_3 = BC_d{374:621,112+i}; %1996:05-2016:12
    BC_i = vertcat(BC_2, BC_3);
    
    Fed_2 = Fed_d{346:369,4+i}; %1994:01-1995:12
    Fed_3 = Fed_d{374:621,4+i}; %1996:05-2016:12 
    Fed_i = vertcat(Fed_2,Fed_3);

    BC_t3m2 = BC_d{346:369,32+i}; %1994:01 - 1995:09  -- Z - 3 Month Treasury Bill Yield
    BC_t3m3 = BC_d{374:621,32+i}; %1996:05-2016:12   -- Z - 3 Month Treasury Bill Yield
    BC_t3m = vertcat(BC_t3m2, BC_t3m3);
    
    BC_u2 = BC_d{346:369,42+i}; %1994:01 - 1995:09  -- Z - unemployment rate 
    BC_u3 = BC_d{374:621,42+i}; %1996:05-2016:12  -- Z - unemployment rate 
    BC_u = vertcat(BC_u2, BC_u3);

    BC_y2 = BC_d{346:369,102+i}; %1994:01 - 1995:09  -- Z - Real Gross Domestic Product
    BC_y3 = BC_d{374:621,102+i}; %1996:05-2016:12  -- Z - Real Gross Domestic Product
    BC_y = vertcat(BC_y2, BC_y3);


    %First stage regression
    A = size(BC_i,1);
    x = [ones(A,1) BC_i BC_t3m BC_u BC_y]; 
    %1st stage: OLS regression
    result_A{i,3} = ols2(Fed_i,x);
    fid = fopen('result_A.out','a+');
    prt_reg2(result_A{i,3}, [],fid);
    %F-stat that IV = 0
    fstat_Table2_F{i,3} = waldf_1st_stage_multi3(result_A{i,3});
    fid = fopen('Table2_a1994.out','a+');
    prt_reg_f(fstat_Table2_F{i,3}, [],fid);

    
    %Second Stage Regression
    A = size(Fed_i,1);
    xex = [ones(A,1) BC_i]; %includes ones and controls
    iv = [BC_t3m BC_u BC_y];
    vnames = strvcat('inf','Fed IV','const','BC');
    T = table(date,inf,BC_i,Fed_i,BC_t3m,BC_u,BC_y);
    %Second Stage - NW errors
    %tslsNW(dependent var,endogenous,all exog/controls,instrument, nlag)
    result_Table2{i,3} = tslsNW4(inf,Fed_i,xex,iv,T); 
    %result_Table2{i,3} = tslsNW(inf,Fed_i,xex,iv); 
    %output: beta = beta_endog beta_exo 
    %var1: Fed_IV, var2: constant, var3: SPF
    fid = fopen('Table2_a1994.out','a+');
    prt_reg2(result_Table2{i,3},vnames,fid);
    %Encompassing Test - F-stat
    %not including intercept as a restriction
    fstat_Table2{i,3} = waldf_IVa(result_Table2{i,3});
    fid = fopen('Table2_a1994.out','a+');
    prt_reg_f(fstat_Table2{i,3}, [],fid);
    
end    
