%Table 4: Monetary Policy Path Encompassing Test Results - Inflation
%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%%%%%%%%%%%%%
%
%  Encompassing Test - Split Sample
%
% Tests of Federal Reserve Additional Information for GNP/GDP Price Index Forecasts: 
% u_{h,t} = \delta + \gamma_{C} \hat{u}_{h,t}^{C} + \gamma_{F} \hat{u}_{h,t}^{F} +\nu_{h,t} 
%
% Blue Chip & Greenbook/Fed
%
%%%%%%%%%%%%%%%%%%%

addpath(genpath('/Applications/MATLAB_R2021b.app/toolbox/LeSage/'))

%load data
Actual_d = readtable('Data_main.xlsx','Sheet','Actual','ReadRowNames',1); 
BC_d = readtable('Data_main.xlsx','Sheet','BC_data','ReadRowNames',1); 
Fed_d = readtable('Data_main.xlsx','Sheet','Greenbook_data','ReadRowNames',1); 

%Storing results for regressions
result_Table4=cell(5,4);  %Newey-West
 
%Storing results for F-tests
fstat_Table4=cell(5,4);

%%% Full Sample

%Loop for regressions and F-tests
for i = 1:5 
    
    %full data set 1982:01 - 1995:11, 1996:05-2012:12
    t2 = datetime(1965,04,01);
    t22 = dateshift(t2,'start','month',0:668)';
    date_all = t22(1:669,1); %1965:04 - 2020:12 
    
    date1 = date_all(202:320,1); %1982:01 - 1991:11 
    date2 = date_all(322:369,1); %1992:01-1995:12
    date3 = date_all(374:621,1); %1996:05-2016:12
    datet = vertcat(date1,date2,date3);

    inf1= Actual_d{199+3*i:317+3*i,3}; %first final release 1982:01 - 1991:11 GNP def
    inf2 = Actual_d{319+3*i:366+3*i,6}; %1992:01 - 1995:12 Price index for GDP, implicit deflator
    inf3= Actual_d{371+3*i:618+3*i,9}; %1996:05-2016:12 GDP, chain weighted
    inf = vertcat(inf1,inf2,inf3);
    
    BC_1 = BC_d{202:320,112+i}; %1982:01 - 1991:11 
    BC_2 = BC_d{322:369,112+i}; %1992:01-1995:12
    BC_3 = BC_d{374:621,112+i}; %1996:05-2016:12
    BC_i = vertcat(BC_1,BC_2, BC_3);
    
    Fed_1 = Fed_d{202:320,4+i}; %1982:01 - 1991:11
    Fed_2 = Fed_d{322:369,4+i}; %1992:01-1995:12
    Fed_3 = Fed_d{374:621,4+i}; %1996:05-2016:12 
    Fed_i = vertcat(Fed_1,Fed_2,Fed_3);
   
    %%%%%%%%%%%
    %path variables
    
    %GB on path, tau = 0.05
    %once not on path, never on path for future horizons
    GB_p = readtable('Measures/GB_FFR.xlsx','Sheet','GB_S05_MTO_q_p'); %t05_full
    GB_p_zlb = readtable('Measures/GB10Y.xlsx','Sheet','GB10Y_S1_MTO_q_p'); %_t05_t5_full
    GB_s1 = GB_p{13:131,1+i}; %1982:01 - 1991:11
    GB_s2 = GB_p{133:180,1+i}; %1992:01-1995:12
    GB_s3 = GB_p{185:333,1+i}; %1996:05-2008:09
    GB_s3a = GB_p_zlb{104:189,1+i}; %2008:10-2015:11 %10Y
    GB_s3b = GB_p{420:432,1+i}; %2015:12-2016:12
    GB_sp = vertcat(GB_s1,GB_s2,GB_s3,GB_s3a,GB_s3b);


    %GB doesn't know the path, tau = 0.05
    %once not on path, never on path for future horizons
    GB_p = readtable('Measures/GB_FFR.xlsx','Sheet','GB_S05_MTO_q_np'); %t05_full
    GB_p_zlb = readtable('Measures/GB10Y.xlsx','Sheet','GB10Y_S1_MTO_q_np'); %_t05_t5_full
    GB_s1 = GB_p{13:131,1+i}; %1982:01 - 1991:11
    GB_s2 = GB_p{133:180,1+i}; %1992:01-1995:12
    GB_s3 = GB_p{185:333,1+i}; %1996:05-2008:09
    GB_s3a = GB_p_zlb{104:189,1+i}; %2008:10-2015:11 %10Y
    GB_s3b = GB_p{420:432,1+i}; %2015:12-2016:12
    GB_snp = vertcat(GB_s1,GB_s2,GB_s3,GB_s3a,GB_s3b);

    
    %BC knows the path, tau = 0.05
    %quarterly average ED indicator
    %once not on path, never on path for future horizons
    mkt_np =readtable('Measures/EuroDollar_q.xlsx','Sheet','ir_S05_MTO_p'); %t05_full
    mkt_np_zlb = readtable('Measures/T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO_p'); %10Y Futures
    mkt_s1 = mkt_np{1:119,1+i}; %1982:01 - 1991:11
    mkt_s2 = mkt_np{121:168,1+i}; %1992:01-1995:12 
    mkt_s3 = mkt_np{173:321,1+i}; %1996:05-2008:09
    mkt_s3a = mkt_np_zlb{322:407,1+i}; %2008:10-2015:11 10Y futures & BC
    mkt_s3b = mkt_np{408:420,1+i}; %2015:12-2016:12
    mkt_sp = vertcat(mkt_s1,mkt_s2,mkt_s3,mkt_s3a,mkt_s3b);

    %BC doesn't know the path, tau = 0.05
    %quarterly average ED indicator
    %once not on path, never on path for future horizons
    mkt_np = readtable('Measures/EuroDollar_q.xlsx','Sheet','ir_S05_MTO_np'); %t05_full
    mkt_np_zlb = readtable('Measures/T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO_np'); %10Y Futures
    mkt_s1 = mkt_np{1:119,1+i}; %1982:01 - 1991:11
    mkt_s2 = mkt_np{121:168,1+i}; %1992:01-1995:12  
    mkt_s3 = mkt_np{173:321,1+i}; %1996:05-2008:09 
    mkt_s3a = mkt_np_zlb{322:407,1+i}; %2008:10-2015:11 10Y futures & BC
    mkt_s3b = mkt_np{408:420,1+i}; %2015:12-2016:12
    mkt_snp = vertcat(mkt_s1,mkt_s2,mkt_s3,mkt_s3a,mkt_s3b);

    %%%%%%%%%%%
    %uncertainty variables
    MPU_MP = readtable('Measures/MPU_MP.xlsx','Sheet','MPU_MP');
    %Certain - lower 40%
    c40_w1 = zeros(36,1);
    c40_w2 = MPU_MP{1:83,14}; %1985:01 - 1991:11
    c40_w3 = MPU_MP{85:132,14}; %1992:01-1995:12 
    c40_w4 = MPU_MP{137:384,14}; %1996:05-2016:12 
    c40_w = vertcat(c40_w1,c40_w2,c40_w3,c40_w4);
    
    %Uncertain - upper 60%
    u60_w1 = zeros(36,1);
    u60_w2 = MPU_MP{1:83,17}; %1985:01 - 1991:11
    u60_w3 = MPU_MP{85:132,17}; %1992:01-1995:12 
    u60_w4 = MPU_MP{137:384,17}; %1996:05-2016:12 
    u60_w = vertcat(u60_w1,u60_w2,u60_w3,u60_w4);
    
    
    %%%%%%%%
    %Panel A
    %both on or both off path
    %%%%%%%%
    
    %observations both not on path
    np = mkt_snp .* GB_snp;
    %observations both on path
    p = mkt_sp .* GB_sp;
    %observations where both are on or off path
    tmp = cat(3,np,p); 
    s = nansum(tmp,3);
    s(s==0) = NaN;
    
    A = size(BC_i,1);
    BC_s = BC_i .* s;
    Fed_s = Fed_i.* s;
    x = [ones(A,1) BC_s Fed_s];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(datet,inf,BC_s,Fed_s);
    
    %Newey-West 
    result_Table4{i,1} = nwest3_en(inf,x,T);
    fid = fopen('Table4_A.out','a+');
    prt_reg_nw(result_Table4{i,1},vnames,fid);
    %F-test
    %not testing intercept
    fstat_Table4{i,1} = waldf_table2a(result_Table4{i,1});
    fid = fopen('Table4_A.out','a+');
    prt_reg_f(fstat_Table4{i,1}, [],fid)
  
    
    %%%%%%%%
    %Panel B
    % Fed on path; market not on path
    %%%%%%%%
    
    A = size(BC_i,1);
    BC_nopath = BC_i .* mkt_snp;
    Fed_path = Fed_i.*GB_sp;
    x = [ones(A,1) BC_nopath Fed_path];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(datet,inf,BC_nopath,Fed_path);
    
    %Newey-West - known path
    result_Table4{i,2} = nwest3_en(inf,x,T);
    fid = fopen('Table4_B.out','a+');
    prt_reg_nw(result_Table4{i,2},vnames,fid);
    %F-test
    %not testing intercept
    fstat_Table4{i,2} = waldf_table2a(result_Table4{i,2});
    fid = fopen('Table4_B.out','a+');
    prt_reg_f(fstat_Table4{i,2}, [],fid)
    
   
    %%%%%%%%
    %Panel D
    % 1. Fed on path; market on path & low uncertainty
    % 2. Fed off path; market is off path or uncertain
    %%%%%%%%
    
    %observations where market on path & low uncertainty
    sc = mkt_sp .* c40_w;
    sc(sc==0) = NaN;
    %observations both on path
    p = sc .* GB_sp;
    
    %observations where market is off path or uncertain
    tmp = cat(3,mkt_snp,u60_w); 
    su = nansum(tmp,3);
    su(su==0) = NaN;
    su(su==2) = 1;
    %observations both not on path
    np = su .* GB_snp;
    
    %observations where both are on or off path
    tmp = cat(3,np,p); 
    s = nansum(tmp,3);
    s(s==0) = NaN; 

    A = size(BC_i,1);
    BC_s = BC_i .* s;
    Fed_s = Fed_i.* s;
    x = [ones(A,1) BC_s Fed_s];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(datet,inf,BC_s,Fed_s);
    
    %Newey-West 
    result_Table4{i,4} = nwest3_en(inf,x,T);
    fid = fopen('Table4_D.out','a+');
    prt_reg_nw(result_Table4{i,4},vnames,fid);
    %F-test
    %not testing intercept
    fstat_Table4{i,4} = waldf_table2a(result_Table4{i,4});
    fid = fopen('Table4_D.out','a+');
    prt_reg_f(fstat_Table4{i,4}, [],fid)
    
    
    %%%%%%%%
    %Panel C
    % Fed on path; market off path or uncertain
    %%%%%%%%
    %observations where off path or uncertain
    tmp = cat(3,mkt_snp,u60_w); 
    su = nansum(tmp,3);
    su(su==0) = NaN;
    su(su==2) = 1;
    
    A = size(BC_i,1);
    BC_nopath = BC_i .* su;
    Fed_path = Fed_i.*GB_sp;
    x = [ones(A,1) BC_nopath Fed_path];
    vnames = strvcat('inf','const','BC','Fed');
    
    T = table(datet,inf,BC_nopath,Fed_path);
    
    %Newey-West - known path
    result_Table4{i,3} = nwest3_en(inf,x,T);
    fid = fopen('Table4_C.out','a+');
    prt_reg_nw(result_Table4{i,3},vnames,fid);
    %F-test
    %not testing intercept
    fstat_Table4{i,3} = waldf_table2a(result_Table4{i,3});
    fid = fopen('Table4_C.out','a+');
    prt_reg_f(fstat_Table4{i,3}, [],fid)
    
end