% Table 5 - Forecast Error & Monetary Policy Path
%Guisinger, McCracken, & Owyang
%Reconsidering the Fed%s Inflation Forecasting Advantage

%%%%%%%%%%%%%%%%%%%
%
% Overall Accuracy of Forecasts - MSE
% on & off monetaty policy path
%
%%%%%%%%%%%%%%%%%%%

addpath(genpath('/Applications/MATLAB_R2021b.app/toolbox/LeSage/'))

%load data
Actual_d = readtable('Data_main.xlsx','Sheet','Actual','ReadRowNames',1); 
BC_d = readtable('Data_main.xlsx','Sheet','BC_data','ReadRowNames',1); 
Fed_d = readtable('Data_main.xlsx','Sheet','Greenbook_data','ReadRowNames',1); 

result_rsmfe_BC_MP=cell(5,4); %MP sample  - Blue Chip & Fed

%Loop for Blue Chip & Fed MP sample
for i = 1:5
    
    %full data set 1982:01 - 1995:11, 1996:05-2016:12
    inf1= Actual_d{199+3*i:317+3*i,3}; %first final release 1982:01 - 1991:11 GNP def
    inf2 = Actual_d{319+3*i:366+3*i,6}; %1992:01 - 1995:12 Price index for GDP, implicit deflator
    inf3= Actual_d{371+3*i:618+3*i,9}; %1996:05-2016:12 GDP, chain weighted
    inf = vertcat(inf1,inf2,inf3);
    
    BC_1 = BC_d{202:320,112+i}; %1982:01 - 1991:11 
    BC_2 = BC_d{322:369,112+i}; %1992:01-1995:12
    BC_3 = BC_d{374:621,112+i}; %1996:05-2016:12
    BC_i = vertcat(BC_1,BC_2, BC_3);

    Fed_1 = Fed_d{202:320,4+i}; %1982:01 - 1991:11
    Fed_2 = Fed_d{322:369,4+i}; %1992:01-1995:12
    Fed_3 = Fed_d{374:621,4+i}; %1996:05-2016:12 
    Fed_i = vertcat(Fed_1,Fed_2,Fed_3);

    %%%%%%%%%%%
    %path variables
    
    %GB on path, tau = 0.05
    %once not on path, never on path for future horizons
    GB_p = readtable('Measures/GB_FFR.xlsx','Sheet','GB_S05_MTO_q_p'); %t05_full
    GB_p_zlb = readtable('Measures/GB10Y.xlsx','Sheet','GB10Y_S1_MTO_q_p'); %_t05_t5_full
    GB_s1 = GB_p{13:131,1+i}; %1982:01 - 1991:11
    GB_s2 = GB_p{133:180,1+i}; %1992:01-1995:12
    GB_s3 = GB_p{185:333,1+i}; %1996:05-2008:09
    GB_s3a = GB_p_zlb{104:189,1+i}; %2008:10-2015:11 %10Y
    GB_s3b = GB_p{420:432,1+i}; %2015:12-2016:12
    GB_sp = vertcat(GB_s1,GB_s2,GB_s3,GB_s3a,GB_s3b);

    %GB doesn't know the path, tau = 0.05
    %once not on path, never on path for future horizons
    GB_p = readtable('Measures/GB_FFR.xlsx','Sheet','GB_S05_MTO_q_np'); %t05_full
    GB_p_zlb = readtable('Measures/GB10Y.xlsx','Sheet','GB10Y_S1_MTO_q_np'); %_t05_t5_full
    GB_s1 = GB_p{13:131,1+i}; %1982:01 - 1991:11
    GB_s2 = GB_p{133:180,1+i}; %1992:01-1995:12
    GB_s3 = GB_p{185:333,1+i}; %1996:05-2008:09
    GB_s3a = GB_p_zlb{104:189,1+i}; %2008:10-2015:11 %10Y
    GB_s3b = GB_p{420:432,1+i}; %2015:12-2016:12
    GB_snp = vertcat(GB_s1,GB_s2,GB_s3,GB_s3a,GB_s3b);

    %BC knows the path, tau = 0.05
    %quarterly average ED indicator
    %once not on path, never on path for future horizons
    mkt_np =readtable('Measures/EuroDollar_q.xlsx','Sheet','ir_S05_MTO_p'); %t05_full
    mkt_np_zlb = readtable('Measures/T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO_p'); %10Y Futures
    mkt_s1 = mkt_np{1:119,1+i}; %1982:01 - 1991:11
    mkt_s2 = mkt_np{121:168,1+i}; %1992:01-1995:12 
    mkt_s3 = mkt_np{173:321,1+i}; %1996:05-2008:09
    mkt_s3a = mkt_np_zlb{322:407,1+i}; %2008:10-2015:11 10Y futures & BC
    mkt_s3b = mkt_np{408:420,1+i}; %2015:12-2016:12
    mkt_sp = vertcat(mkt_s1,mkt_s2,mkt_s3,mkt_s3a,mkt_s3b);

    %BC doesn't know the path, tau = 0.05
    %quarterly average ED indicator
    %once not on path, never on path for future horizons
    mkt_np = readtable('Measures/EuroDollar_q.xlsx','Sheet','ir_S05_MTO_np'); %t05_full
    mkt_np_zlb = readtable('Measures/T10YFutures_q.xlsx','Sheet','F10yF_S1_MTO_np'); %10Y Futures
    mkt_s1 = mkt_np{1:119,1+i}; %1982:01 - 1991:11
    mkt_s2 = mkt_np{121:168,1+i}; %1992:01-1995:12 
    mkt_s3 = mkt_np{173:321,1+i}; %1996:05-2008:09 
    mkt_s3a = mkt_np_zlb{322:407,1+i}; %2008:10-2015:11 10Y futures & BC
    mkt_s3b = mkt_np{408:420,1+i}; %2015:12-2016:12
    mkt_snp = vertcat(mkt_s1,mkt_s2,mkt_s3,mkt_s3a,mkt_s3b);

    
    %observations both on path
    p = mkt_sp .* GB_sp;
    
    BC_s = BC_i .* p;
    Fed_s = Fed_i.* p;
    x = [BC_s Fed_s];
    result_rsmfe_BC_MP{i,1} = rmsfe(inf,x); 
   
    %observations market on path
    BC_s = BC_i .* mkt_sp;
    Fed_s = Fed_i .* mkt_sp;
    x = [BC_s Fed_s];
    result_rsmfe_BC_MP{i,2} = rmsfe(inf,x); 
    
    %observations market not on path
    BC_s = BC_i .* mkt_snp;
    Fed_s = Fed_i.* mkt_snp;
    x = [BC_s Fed_s];
    result_rsmfe_BC_MP{i,3} = rmsfe(inf,x);

    %observations Fed on path & market not on path
    BC_s = BC_i .* mkt_snp;
    Fed_s = Fed_i.* GB_sp;
    x = [BC_s Fed_s];
    result_rsmfe_BC_MP{i,4} = rmsfe(inf,x); 
end


