function result = waldf_IVa(resultu)
% PURPOSE: computes Wald F-test
% where coefficient on IV = 1 & other forecast = 0
% two restrictions
%---------------------------------------------------
% USAGE: [fstat fprob] = waldf_table1(resultr,resultu)
% Where: resultu = results structure from ols() unrestrcted regression
%---------------------------------------------------
% RETURNS: fstat = {(essr - essu)/#restrict}/{essu/(nobs-nvar)} 
%          fprb  = marginal probability for fstat
% NOTE:  large fstat => reject the restrictions as inconsisent 
%                       with the data
%---------------------------------------------------
% Edited from Spatial Econometrics Toolbox by James P. LeSage 

% betahat and varaince-covariance matrix
betahat = resultu.beta;
Var = resultu.covar;
n = resultu.nobs;

% R and r matrices
R = [1 0 0; 0 0 1] ; 
r = [1;0] ;
q = size(r,1); %restrictions
% The Wald test statistic
diff = R*betahat - r ; Vdiff = R*Var*R' ;
W=diff'*inv(Vdiff)*diff ;
%approximate F stat
F = W/q;
% The rejection region
df = size(R,1); alpha = 0.05 ;
Reject = chi2inv(1-alpha, df);
chiprb = 1-chi2cdf(W,q);
fprb = fdis_prb(F,q,n-q); %fstat, # of restrictions, degrees of freedom

result.W = W;
result.chiprb = chiprb;
result.Reject = Reject;
result.q = q;
result.F = F;
result.fprb = fprb;

%fprintf(1,'Wald              = %16.8f \n',W);
%fprintf(1,'Wald F-statistic = %16.8f \n',F);
%fprintf(1,'probability      = %16.4f \n',fprb);
%fprintf(1,'restriction, dof    = %4d,%4d\n',q,(n-q));