*******************************************************************************
****************************	SET DIRECTORIES	 *******************************
********************************************************************************

clear

gl other = 0
gl ngan = 1
assert $other + $ngan == 1


if $other == 1 {
gl workdir "YOUR DIRECTORY HERE"
gl datadir "${workdir}/Data"
gl outputdir "${workdir}/Results"
}


if $ngan == 1 {
gl workdir "G:\Research_Analyst\Tran\Mike\Research\GreenBook data\GreenBook_Transcribe"
gl datadir "${workdir}\Data"
gl outputdir "${workdir}\Results"

}

set more off 

*******************************************************************************
*******************************	INTERPOLATION	*******************************
********************************************************************************
*** INTERPOLATE DATA FROM 2014 to 2016 

local firstyear = 2014
local lastyear = 2016
local graphs FFR 10YR 

foreach year of numlist `firstyear'/`lastyear' {
	foreach meeting of numlist 1/8 {
		foreach graph of local graphs {
capture noisily{
	//CHANGE EXCEL NAME 
import excel "${datadir}/`graph'_raw_redo.xlsx", sheet("`graph'`year'`meeting'") clear
split A, parse(,)
ren A1 year_raw
destring year_raw, replace
ren A2 rate_raw
destring rate_raw, replace

sort year_raw
local counter = _N
disp `counter'

local lowyear = round(year_raw[1],1)
disp `lowyear'

local highyear = round(year_raw[`counter'],1)
disp `highyear'

local quarters = (`highyear'-`lowyear')*4

save "${datadir}\temp\raw", replace

clear
set obs `quarters'
gen year_raw = .

foreach num of numlist 1/`quarters' {
	if `num' == 1 {
		local quarter = `lowyear' - 0.125
	}
	local quarter = `quarter' + 0.25
	replace year_raw = `quarter' in `num'
}


append using "${datadir}\temp\raw"
	
sort year_raw
gen year_lag = year_raw[_n-1]
gen year_lead = year_raw[_n+1]
gen rate_lag = rate_raw[_n-1]
gen rate_lead = rate_raw[_n+1]

foreach num of numlist 1/10 {
	replace rate_lag = rate_lag[_n-1] if rate_lag == .	
	replace rate_lead = rate_lead[_n+1] if rate_lead == .	
}

drop if rate_raw != .
ren year_raw year_clean

gen rate_clean = rate_lag + ((year_clean-year_lag)*(rate_lead-rate_lag))/(year_lead-year_lag)

tostring year_clean, replace
gen year = substr(year_clean,1,4)
destring year, replace
gen quarter_raw = substr(year_clean,6,3)
destring quarter_raw, replace
gen quarter = 0
replace quarter = 1 if quarter_raw == 125
replace quarter = 2 if quarter_raw == 375
replace quarter = 3 if quarter_raw == 625
replace quarter = 4 if quarter_raw == 875
gen date = yq(year,quarter)
format date %tq
keep year quarter rate_clean date
order date year quarter rate_clean

export excel using "${datadir}\Master_Clean_1416.xlsx", sheet("`graph'`year'`meeting'") sheetreplace		
}
		}
	}
}


*******************************************************************************
******************	RESHAPE DATA BY ORIGIN AND HORIZON	************************
********************************************************************************

clear 
gen temp = ""
save "${datadir}\Master_Full_1416", replace


local graphs FFR 10YR
	local firstyear = 2014
	local lastyear = 2016


foreach year of numlist `firstyear'/`lastyear' {
	foreach meeting of numlist 1/8 {
		foreach graph of local graphs {
			capture noisily{
			import excel "${datadir}\Master_Clean_1416.xlsx", sheet("`graph'`year'`meeting'") clear
			gen meeting = `meeting'
			gen year = `year'
			cd "$datadir"
			merge m:1 year meeting using crosswalk 
			
			drop if _merge != 3
			drop _merge
			
			//generate forecast origin: year-month format
			gen meetingM = ym(year, month)
			format meetingM %tm
			
			
			//generate forecast origin: year-quarter (for calculating horizon)
			gen meetingQ = qofd(dofm(ym(year, month)))
			format meetingQ %tq
			
			//generate quarter of forecast date
			gen forecastQ = yq(B,C)
			format forecastQ %tq
			order B C forecastQ			//check. looks good
			
			//generate horizon from forecast date 
			gen horizon = forecastQ - meetingQ
			keep if horizon >= 0 
			ren D lead
		
		
			//reshape data
			keep meetingM horizon lead 
			reshape wide lead, i(meetingM) j(horizon)
			
			//rename horizons
			rename (lead*) (_`graph'*)
			append using "${datadir}\Master_Full_1416"
			
			/// save 
			save "${datadir}\Master_Full_1416", replace
			}
		}
	}
}
drop temp


*** Rearrange 

order _10YR9, after(_10YR8)
order _10YR0, before (_10YR1)
order _FFR0, before(_FFR1)

order _FFR10-_FFR12, after (_FFR9)

order _10YR10-_10YR13, after(_10YR9)


sort meetingM

*** Remove columns (horizons) with all missing observations
foreach var of varlist _all {
capture assert mi(`var')
if !_rc {
   drop `var'
}
}

*** Each month has two entries: one with FFR values and empty 10YR, and vice versa.
***	collapse by month so that each year-month is a single entry

collapse (rawsum) _10YR0-_FFR11, by (meetingM)

// Ngan comment: the collapse can be made more dynamic by making the last FFR horizon 
// a local? 

*** Stata treats missing values as zeroes. Change back to missing
foreach var of varlist _all{
	replace `var' = . if `var' == 0
}


*** export to Excel 
rename meetingM date 


// 10YR
preserve
keep date _10YR*
cd "$outputdir"
export excel date _10YR* using "10YR_clean_1416.xlsx", firstrow(variables) keepcellfmt sheet ("10YR", replace) 
restore 


// FFR
preserve
keep date _FFR*
cd "$outputdir"
export excel date _FFR* using "FFR_clean_1416.xlsx", firstrow(variables) keepcellfmt sheet ("FFR", replace) 
restore 


*******************************************************************************
******************	PLOTS FOR COMPARISON TO ORIGINAL TEALBOOKS	****************
********************************************************************************

rename date meetingM
reshape long _FFR _10YR, i(meetingM) j(horizon)



***	generate graph name: forecast origin in year-month
gen month = month(dofm(meetingM))
gen year = year(dofm(meetingM))
tostring month year, replace
egen year_month = concat(year month)


***	generate forecast quarter for graphing 
gen meetingQ = qofd(dofm(meetingM))
format meetingQ %tq

gen forecastQ = meetingQ + horizon
format forecastQ %tq

order meetingQ horizon forecastQ	//check. looks good

*** plotting loop 
levelsof year_month, local(yms)


	 
foreach ym in `yms' {
	///FFR graphs 
		preserve
		keep if year_month =="`ym'"
		local year = substr("`ym'", 1, 4)
		cd "$outputdir\graphs\FFR/`year'"
		line _FFR forecastQ, ylab(0(1)6) title("FFR_`ym'")
		graph export FFR_`ym'_redo.png, replace 
		restore
		}
		

foreach ym in `yms' {
	///10YR graphs 
		preserve
		keep if year_month =="`ym'"
		local year = substr("`ym'", 1, 4)
		cd "$outputdir\graphs\10YR/`year'"
		line _10YR forecastQ, ylab(0(1)6) title("10YR_`ym'")
		graph export 10YR_`ym'_redo.png, replace 
		restore
		}
	