/*
This code reads in raw FFR and 10-year forecasts from the Board's GreenBook PDFs from 
2009 to 2016 obtained using GraphReader, interpolates quarterly forecasts, rearranges 
forecasts by origin (month of FOMC meeting) and horizon (quarters ahead), and produces 
plots for comparing interpolated data to original plots 

Author: Jason Dunn, adapted by Ngan Tran

Date:	8/6/2022

*/

*******************************************************************************
****************************	SET DIRECTORIES	 *******************************
********************************************************************************

clear

gl other = 0
gl ngan = 1
assert $other + $ngan == 1


if $other == 1 {
gl workdir "YOUR DIRECTORY HERE"
gl datadir "${workdir}/Data"
gl outputdir "${workdir}/Results"
}


if $ngan == 1 {
gl workdir "G:\Research_Analyst\Tran\Mike\Research\GreenBook data\GreenBook_Transcribe"
gl datadir "${workdir}\Data"
gl outputdir "${workdir}\Results"

}

set more off 

*******************************************************************************
*******************************	INTERPOLATION	*******************************
********************************************************************************

gl yearStart_2008 = 1							//STEP 1. change to 1 to interpolate data for the last two meetings of 2008
gl yearStart_2009 = 0							//STEP 2. then change this to 1 AND yearStart_2008 to zero to interpolate the rest of the data
assert $yearStart_2008 + $yearStart_2009 == 1

/*******************************************************************************/
***	INTERPOLATE 2008 DATA 

if $yearStart_2008 == 1{
	local year = 2008
	local graphs FFR 10YR
	foreach meeting of numlist 7/8 {
		foreach graph of local graphs {
		cd "$datadir"
import excel using "`graph'_raw.xlsx", sheet("`graph'`year'`meeting'") clear
split A, parse(,)
ren A1 year_raw
destring year_raw, replace
ren A2 rate_raw
destring rate_raw, replace

sort year_raw
local counter = _N
disp `counter'

local lowyear = round(year_raw[1],1)
disp `lowyear'

local highyear = round(year_raw[`counter'],1)
disp `highyear'

local quarters = (`highyear'-`lowyear')*4

save "${datadir}/temp/raw", replace

clear
set obs `quarters'
gen year_raw = .

foreach num of numlist 1/`quarters' {
	if `num' == 1 {
		local quarter = `lowyear' - 0.125
	}
	local quarter = `quarter' + 0.25
	replace year_raw = `quarter' in `num'
}

append using "${datadir}/temp/raw"
	
sort year_raw
gen year_lag = year_raw[_n-1]
gen year_lead = year_raw[_n+1]
gen rate_lag = rate_raw[_n-1]
gen rate_lead = rate_raw[_n+1]

foreach num of numlist 1/10 {
	replace rate_lag = rate_lag[_n-1] if rate_lag == .	
	replace rate_lead = rate_lead[_n+1] if rate_lead == .	
}

drop if rate_raw != .
ren year_raw year_clean

gen rate_clean = rate_lag + ((year_clean-year_lag)*(rate_lead-rate_lag))/(year_lead-year_lag)

tostring year_clean, replace
gen year = substr(year_clean,1,4)
destring year, replace
gen quarter_raw = substr(year_clean,6,3)
destring quarter_raw, replace
gen quarter = 0
replace quarter = 1 if quarter_raw == 125
replace quarter = 2 if quarter_raw == 375
replace quarter = 3 if quarter_raw == 625
replace quarter = 4 if quarter_raw == 875
gen date = yq(year,quarter)
format date %tq
keep year quarter rate_clean date
order date year quarter rate_clean

export excel using "${datadir}\Master_Clean.xlsx", sheet("`graph'`year'`meeting'") sheetreplace		
		}
	}
}

/*******************************************************************************/
***	INTERPOLATE THE REST OF DATA (2009 TO 2016)

if $yearStart_2009 == 1{

local firstyear = 2009
local lastyear = 2016
local graphs FFR 10YR 

foreach year of numlist `firstyear'/`lastyear' {
	foreach meeting of numlist 1/8 {
		foreach graph of local graphs {
import excel "${datadir}\`graph'_raw.xlsx", sheet("`graph'`year'`meeting'") clear
split A, parse(,)
ren A1 year_raw
destring year_raw, replace
ren A2 rate_raw
destring rate_raw, replace

sort year_raw
local counter = _N
disp `counter'

local lowyear = round(year_raw[1],1)
disp `lowyear'

local highyear = round(year_raw[`counter'],1)
disp `highyear'

local quarters = (`highyear'-`lowyear')*4

save "${datadir}/temp/raw", replace

clear
set obs `quarters'
gen year_raw = .

foreach num of numlist 1/`quarters' {
	if `num' == 1 {
		local quarter = `lowyear' - 0.125
	}
	local quarter = `quarter' + 0.25
	replace year_raw = `quarter' in `num'
}

append using "${datadir}/temp/raw"
	
sort year_raw
gen year_lag = year_raw[_n-1]
gen year_lead = year_raw[_n+1]
gen rate_lag = rate_raw[_n-1]
gen rate_lead = rate_raw[_n+1]

foreach num of numlist 1/10 {
	replace rate_lag = rate_lag[_n-1] if rate_lag == .	
	replace rate_lead = rate_lead[_n+1] if rate_lead == .	
}

drop if rate_raw != .
ren year_raw year_clean

gen rate_clean = rate_lag + ((year_clean-year_lag)*(rate_lead-rate_lag))/(year_lead-year_lag)

tostring year_clean, replace
gen year = substr(year_clean,1,4)
destring year, replace
gen quarter_raw = substr(year_clean,6,3)
destring quarter_raw, replace
gen quarter = 0
replace quarter = 1 if quarter_raw == 125
replace quarter = 2 if quarter_raw == 375
replace quarter = 3 if quarter_raw == 625
replace quarter = 4 if quarter_raw == 875
gen date = yq(year,quarter)
format date %tq
keep year quarter rate_clean date
order date year quarter rate_clean

export excel using "${datadir}\Master_Clean.xlsx", sheet("`graph'`year'`meeting'") sheetmodify			
		}
	}
}

}


*******************************************************************************
******************	RESHAPE DATA BY ORIGIN AND HORIZON	************************
********************************************************************************

gen temp = ""
save "${datadir}\Master_Full", replace

local graphs FFR 10YR
local firstyear = 2009
local lastyear = 2010


foreach year of numlist `firstyear'/`lastyear' {
	foreach meeting of numlist 1/8 {
		foreach graph of local graphs {
			import excel "${datadir}\Master_Clean.xlsx", sheet("`graph'`year'`meeting'") clear
			gen meeting = `meeting'
			gen year = `year'
			merge m:1 year meeting using crosswalk 
			drop if _merge != 3
			drop _merge
			
			//generate forecast origin: year-month format
			gen meetingM = ym(year, month)
			format meetingM %tm
			
			
			//generate forecast origin: year-quarter (for calculating horizon)
			gen meetingQ = qofd(dofm(ym(year, month)))
			format meetingQ %tq
			
			//generate quarter of forecast date
			gen forecastQ = yq(B,C)
			format forecastQ %tq
			order B C forecastQ			//check. looks good
			
			//generate horizon from forecast date 
			gen horizon = forecastQ - meetingQ
			keep if horizon >= 0 
			ren D lead
		
		
			//reshape data
			keep meetingM horizon lead 
			reshape wide lead, i(meetingM) j(horizon)
			
			//rename horizons
			rename (lead*) (_`graph'*)
			append using "${datadir}\Master_Full"
			
			/// save 
			save "${datadir}\Master_Full", replace
		}
	}
}
drop temp

order _10YR9, after(_10YR8)
order _10YR0, before (_10YR1)
order _FFR0, before(_FFR1)


sort meetingM

*** Each month has two entries: one with FFR values and empty 10YR, and vice versa.
***	collapse by month so that each year-month is a single entry

collapse (rawsum) _10YR0-_FFR9, by (meetingM)

*** Stata treats missing values as zeroes. Change back to missing
foreach var of varlist _all{
	replace `var' = . if `var' == 0
}


*** export to Excel 
rename meetingM date 

// 10YR
preserve
keep date _10YR*
cd "$outputdir"
export excel date _10YR* using "10YR_clean.xlsx", firstrow(variables) keepcellfmt sheet ("10YR", replace) 
restore 


// FFR
preserve
keep date _FFR*
cd "$outputdir"
export excel date _FFR* using "FFR_clean.xlsx", firstrow(variables) keepcellfmt sheet ("FFR", replace) 
restore 


*******************************************************************************
******************	PLOTS FOR COMPARISON TO ORIGINAL TEALBOOKS	****************
********************************************************************************

rename date meetingM
reshape long _FFR _10YR, i(meetingM) j(horizon)



***	generate graph name: forecast origin in year-month
gen month = month(dofm(meetingM))
gen year = year(dofm(meetingM))
tostring month year, replace
egen year_month = concat(year month)


***	generate forecast quarter for graphing 
gen meetingQ = qofd(dofm(meetingM))
format meetingQ %tq

gen forecastQ = meetingQ + horizon
format forecastQ %tq

order meetingQ horizon forecastQ	//check. looks good

*** plotting loop 
levelsof year_month

foreach lev in `r(levels)' {
		preserve
		keep if year_month =="`lev'"
		cd "$outputdir\graphs\FFR" 
		line _FFR forecastQ, ylab(0(1)6) title("FFR_`lev'")
		graph export FFR_`lev'.png, replace 
		
		cd "$outputdir\graphs\10YR" 
		line _10YR forecastQ, ylab(1(1)10) title("10YR_`lev'")
		graph export 10YR_`lev'.png, replace 
		restore
	}







*******************************************************************************
***********************	MERGE WITH FULL SET OF DATE?****************************
********************************************************************************





